@@ -1,7 +1,6 @@
 from __future__ import annotations
 
-import sys
-from io import BytesIO, StringIO
+from io import BytesIO
 
 import pytest
 
@@ -12,21 +11,78 @@ from .helper import assert_image_equal, hopper
 TEST_FILE = "Tests/images/iptc.jpg"
 
 
+def create_iptc_image(info: dict[str, int] = {}) -> BytesIO:
+    def field(tag, value):
+        return bytes((0x1C,) + tag + (0, len(value))) + value
+
+    data = field((3, 60), bytes((info.get("layers", 1), info.get("component", 0))))
+    data += field((3, 120), bytes((info.get("compression", 1),)))
+    if "band" in info:
+        data += field((3, 65), bytes((info["band"] + 1,)))
+    data += field((3, 20), b"\x01")  # width
+    data += field((3, 30), b"\x01")  # height
+    data += field(
+        (8, 10),
+        bytes((info.get("data", 0),)),
+    )
+
+    return BytesIO(data)
+
+
 def test_open() -> None:
     expected = Image.new("L", (1, 1))
 
-    f = BytesIO(
-        b"\x1c\x03<\x00\x02\x01\x00\x1c\x03x\x00\x01\x01\x1c\x03\x14\x00\x01\x01"
-        b"\x1c\x03\x1e\x00\x01\x01\x1c\x08\n\x00\x01\x00"
-    )
+    f = create_iptc_image()
     with Image.open(f) as im:
-        assert im.tile == [("iptc", (0, 0, 1, 1), 25, "raw")]
+        assert im.tile == [("iptc", (0, 0, 1, 1), 25, ("raw", None))]
         assert_image_equal(im, expected)
 
     with Image.open(f) as im:
         assert im.load() is not None
 
 
+def test_field_length() -> None:
+    f = create_iptc_image()
+    f.seek(28)
+    f.write(b"\xff")
+    with pytest.raises(OSError, match="illegal field length in IPTC/NAA file"):
+        with Image.open(f):
+            pass
+
+
+@pytest.mark.parametrize("layers, mode", ((3, "RGB"), (4, "CMYK")))
+def test_layers(layers: int, mode: str) -> None:
+    for band in range(-1, layers):
+        info = {"layers": layers, "component": 1, "data": 5}
+        if band != -1:
+            info["band"] = band
+        f = create_iptc_image(info)
+        with Image.open(f) as im:
+            assert im.mode == mode
+
+            data = [0] * layers
+            data[max(band, 0)] = 5
+            assert im.getpixel((0, 0)) == tuple(data)
+
+
+def test_unknown_compression() -> None:
+    f = create_iptc_image({"compression": 2})
+    with pytest.raises(OSError, match="Unknown IPTC image compression"):
+        with Image.open(f):
+            pass
+
+
+def test_getiptcinfo() -> None:
+    f = create_iptc_image()
+    with Image.open(f) as im:
+        assert IptcImagePlugin.getiptcinfo(im) == {
+            (3, 60): b"\x01\x00",
+            (3, 120): b"\x01",
+            (3, 20): b"\x01",
+            (3, 30): b"\x01",
+        }
+
+
 def test_getiptcinfo_jpg_none() -> None:
     # Arrange
     with hopper() as im:
@@ -101,35 +157,3 @@ def test_getiptcinfo_tiff_none() -> None:
 
     # Assert
     assert iptc is None
-
-
-def test_i() -> None:
-    # Arrange
-    c = b"a"
-
-    # Act
-    with pytest.warns(DeprecationWarning, match="IptcImagePlugin.i"):
-        ret = IptcImagePlugin.i(c)
-
-    # Assert
-    assert ret == 97
-
-
-def test_dump(monkeypatch: pytest.MonkeyPatch) -> None:
-    # Arrange
-    c = b"abc"
-    # Temporarily redirect stdout
-    mystdout = StringIO()
-    monkeypatch.setattr(sys, "stdout", mystdout)
-
-    # Act
-    with pytest.warns(DeprecationWarning, match="IptcImagePlugin.dump"):
-        IptcImagePlugin.dump(c)
-
-    # Assert
-    assert mystdout.getvalue() == "61 62 63 \n"
-
-
-def test_pad_deprecation() -> None:
-    with pytest.warns(DeprecationWarning, match="IptcImagePlugin.PAD"):
-        assert IptcImagePlugin.PAD == b"\0\0\0\0"
