@@ -1,4 +1,5 @@
 from __future__ import annotations
+
 import pytest
 
 from PIL import Image
@@ -7,7 +8,7 @@ from .helper import assert_image_equal, hopper
 
 
 @pytest.mark.parametrize("data_type", ("bytes", "memoryview"))
-def test_sanity(data_type):
+def test_sanity(data_type: str) -> None:
     im1 = hopper()
 
     data = im1.tobytes()
