@@ -1,4 +1,5 @@
 from __future__ import annotations
+
 import pytest
 
 from PIL import Image, ImageMode
@@ -6,7 +7,7 @@ from PIL import Image, ImageMode
 from .helper import hopper
 
 
-def test_sanity():
+def test_sanity() -> None:
     with hopper() as im:
         im.mode
 
@@ -67,8 +68,12 @@ def test_sanity():
     ),
 )
 def test_properties(
-    mode, expected_base, expected_type, expected_bands, expected_band_names
-):
+    mode: str,
+    expected_base: str,
+    expected_type: str,
+    expected_bands: int,
+    expected_band_names: tuple[str, ...],
+) -> None:
     assert Image.getmodebase(mode) == expected_base
     assert Image.getmodetype(mode) == expected_type
     assert Image.getmodebands(mode) == expected_bands
