@@ -78,16 +78,6 @@ def test_mode_F() -> None:
     assert list(im.getdata()) == target
 
 
-@pytest.mark.parametrize("mode", ("BGR;15", "BGR;16", "BGR;24"))
-def test_mode_BGR(mode: str) -> None:
-    data = [(16, 32, 49), (32, 32, 98)]
-    with pytest.warns(DeprecationWarning, match=mode):
-        im = Image.new(mode, (1, 2))
-    im.putdata(data)
-
-    assert list(im.getdata()) == data
-
-
 def test_array_B() -> None:
     # shouldn't segfault
     # see https://github.com/python-pillow/Pillow/issues/1008
