@@ -1,4 +1,6 @@
 from __future__ import annotations
+
+from collections.abc import Generator
 from contextlib import contextmanager
 
 import pytest
@@ -15,7 +17,7 @@ from .helper import (
 
 class TestImagingResampleVulnerability:
     # see https://github.com/python-pillow/Pillow/issues/1710
-    def test_overflow(self):
+    def test_overflow(self) -> None:
         im = hopper("L")
         size_too_large = 0x100000008 // 4
         size_normal = 1000  # unimportant
@@ -27,7 +29,7 @@ class TestImagingResampleVulnerability:
                 # any resampling filter will do here
                 im.im.resize((xsize, ysize), Image.Resampling.BILINEAR)
 
-    def test_invalid_size(self):
+    def test_invalid_size(self) -> None:
         im = hopper()
 
         # Should not crash
@@ -39,7 +41,7 @@ class TestImagingResampleVulnerability:
         with pytest.raises(ValueError):
             im.resize((100, -100))
 
-    def test_modify_after_resizing(self):
+    def test_modify_after_resizing(self) -> None:
         im = hopper("RGB")
         # get copy with same size
         copy = im.resize(im.size)
@@ -50,7 +52,7 @@ class TestImagingResampleVulnerability:
 
 
 class TestImagingCoreResampleAccuracy:
-    def make_case(self, mode, size, color):
+    def make_case(self, mode: str, size: tuple[int, int], color: int) -> Image.Image:
         """Makes a sample image with two dark and two bright squares.
         For example:
         e0 e0 1f 1f
@@ -65,13 +67,14 @@ class TestImagingCoreResampleAccuracy:
 
         return Image.merge(mode, [case] * len(mode))
 
-    def make_sample(self, data, size):
+    def make_sample(self, data: str, size: tuple[int, int]) -> Image.Image:
         """Restores a sample image from given data string which contains
         hex-encoded pixels from the top left fourth of a sample.
         """
         data = data.replace(" ", "")
         sample = Image.new("L", size)
         s_px = sample.load()
+        assert s_px is not None
         w, h = size[0] // 2, size[1] // 2
         for y in range(h):
             for x in range(w):
@@ -82,9 +85,11 @@ class TestImagingCoreResampleAccuracy:
                 s_px[size[0] - x - 1, y] = 255 - val
         return sample
 
-    def check_case(self, case, sample):
+    def check_case(self, case: Image.Image, sample: Image.Image) -> None:
         s_px = sample.load()
         c_px = case.load()
+        assert s_px is not None
+        assert c_px is not None
         for y in range(case.size[1]):
             for x in range(case.size[0]):
                 if c_px[x, y] != s_px[x, y]:
@@ -94,15 +99,16 @@ class TestImagingCoreResampleAccuracy:
                     )
                     assert s_px[x, y] == c_px[x, y], message
 
-    def serialize_image(self, image):
+    def serialize_image(self, image: Image.Image) -> str:
         s_px = image.load()
+        assert s_px is not None
         return "\n".join(
             " ".join(f"{s_px[x, y]:02x}" for x in range(image.size[0]))
             for y in range(image.size[1])
         )
 
     @pytest.mark.parametrize("mode", ("RGBX", "RGB", "La", "L"))
-    def test_reduce_box(self, mode):
+    def test_reduce_box(self, mode: str) -> None:
         case = self.make_case(mode, (8, 8), 0xE1)
         case = case.resize((4, 4), Image.Resampling.BOX)
         # fmt: off
@@ -113,7 +119,7 @@ class TestImagingCoreResampleAccuracy:
             self.check_case(channel, self.make_sample(data, (4, 4)))
 
     @pytest.mark.parametrize("mode", ("RGBX", "RGB", "La", "L"))
-    def test_reduce_bilinear(self, mode):
+    def test_reduce_bilinear(self, mode: str) -> None:
         case = self.make_case(mode, (8, 8), 0xE1)
         case = case.resize((4, 4), Image.Resampling.BILINEAR)
         # fmt: off
@@ -124,7 +130,7 @@ class TestImagingCoreResampleAccuracy:
             self.check_case(channel, self.make_sample(data, (4, 4)))
 
     @pytest.mark.parametrize("mode", ("RGBX", "RGB", "La", "L"))
-    def test_reduce_hamming(self, mode):
+    def test_reduce_hamming(self, mode: str) -> None:
         case = self.make_case(mode, (8, 8), 0xE1)
         case = case.resize((4, 4), Image.Resampling.HAMMING)
         # fmt: off
@@ -135,7 +141,7 @@ class TestImagingCoreResampleAccuracy:
             self.check_case(channel, self.make_sample(data, (4, 4)))
 
     @pytest.mark.parametrize("mode", ("RGBX", "RGB", "La", "L"))
-    def test_reduce_bicubic(self, mode):
+    def test_reduce_bicubic(self, mode: str) -> None:
         case = self.make_case(mode, (12, 12), 0xE1)
         case = case.resize((6, 6), Image.Resampling.BICUBIC)
         # fmt: off
@@ -147,7 +153,7 @@ class TestImagingCoreResampleAccuracy:
             self.check_case(channel, self.make_sample(data, (6, 6)))
 
     @pytest.mark.parametrize("mode", ("RGBX", "RGB", "La", "L"))
-    def test_reduce_lanczos(self, mode):
+    def test_reduce_lanczos(self, mode: str) -> None:
         case = self.make_case(mode, (16, 16), 0xE1)
         case = case.resize((8, 8), Image.Resampling.LANCZOS)
         # fmt: off
@@ -160,7 +166,7 @@ class TestImagingCoreResampleAccuracy:
             self.check_case(channel, self.make_sample(data, (8, 8)))
 
     @pytest.mark.parametrize("mode", ("RGBX", "RGB", "La", "L"))
-    def test_enlarge_box(self, mode):
+    def test_enlarge_box(self, mode: str) -> None:
         case = self.make_case(mode, (2, 2), 0xE1)
         case = case.resize((4, 4), Image.Resampling.BOX)
         # fmt: off
@@ -171,7 +177,7 @@ class TestImagingCoreResampleAccuracy:
             self.check_case(channel, self.make_sample(data, (4, 4)))
 
     @pytest.mark.parametrize("mode", ("RGBX", "RGB", "La", "L"))
-    def test_enlarge_bilinear(self, mode):
+    def test_enlarge_bilinear(self, mode: str) -> None:
         case = self.make_case(mode, (2, 2), 0xE1)
         case = case.resize((4, 4), Image.Resampling.BILINEAR)
         # fmt: off
@@ -182,7 +188,7 @@ class TestImagingCoreResampleAccuracy:
             self.check_case(channel, self.make_sample(data, (4, 4)))
 
     @pytest.mark.parametrize("mode", ("RGBX", "RGB", "La", "L"))
-    def test_enlarge_hamming(self, mode):
+    def test_enlarge_hamming(self, mode: str) -> None:
         case = self.make_case(mode, (2, 2), 0xE1)
         case = case.resize((4, 4), Image.Resampling.HAMMING)
         # fmt: off
@@ -193,7 +199,7 @@ class TestImagingCoreResampleAccuracy:
             self.check_case(channel, self.make_sample(data, (4, 4)))
 
     @pytest.mark.parametrize("mode", ("RGBX", "RGB", "La", "L"))
-    def test_enlarge_bicubic(self, mode):
+    def test_enlarge_bicubic(self, mode: str) -> None:
         case = self.make_case(mode, (4, 4), 0xE1)
         case = case.resize((8, 8), Image.Resampling.BICUBIC)
         # fmt: off
@@ -206,7 +212,7 @@ class TestImagingCoreResampleAccuracy:
             self.check_case(channel, self.make_sample(data, (8, 8)))
 
     @pytest.mark.parametrize("mode", ("RGBX", "RGB", "La", "L"))
-    def test_enlarge_lanczos(self, mode):
+    def test_enlarge_lanczos(self, mode: str) -> None:
         case = self.make_case(mode, (6, 6), 0xE1)
         case = case.resize((12, 12), Image.Resampling.LANCZOS)
         data = (
@@ -220,7 +226,7 @@ class TestImagingCoreResampleAccuracy:
         for channel in case.split():
             self.check_case(channel, self.make_sample(data, (12, 12)))
 
-    def test_box_filter_correct_range(self):
+    def test_box_filter_correct_range(self) -> None:
         im = Image.new("RGB", (8, 8), "#1688ff").resize(
             (100, 100), Image.Resampling.BOX
         )
@@ -229,34 +235,40 @@ class TestImagingCoreResampleAccuracy:
 
 
 class TestCoreResampleConsistency:
-    def make_case(self, mode, fill):
+    def make_case(
+        self, mode: str, fill: tuple[int, int, int] | float
+    ) -> tuple[Image.Image, float | tuple[int, ...]]:
         im = Image.new(mode, (512, 9), fill)
-        return im.resize((9, 512), Image.Resampling.LANCZOS), im.load()[0, 0]
+        px = im.load()
+        assert px is not None
+        return im.resize((9, 512), Image.Resampling.LANCZOS), px[0, 0]
 
-    def run_case(self, case):
+    def run_case(self, case: tuple[Image.Image, float | tuple[int, ...]]) -> None:
         channel, color = case
         px = channel.load()
+        assert px is not None
         for x in range(channel.size[0]):
             for y in range(channel.size[1]):
                 if px[x, y] != color:
                     message = f"{px[x, y]} != {color} for pixel {(x, y)}"
                     assert px[x, y] == color, message
 
-    def test_8u(self):
+    def test_8u(self) -> None:
         im, color = self.make_case("RGB", (0, 64, 255))
         r, g, b = im.split()
+        assert isinstance(color, tuple)
         self.run_case((r, color[0]))
         self.run_case((g, color[1]))
         self.run_case((b, color[2]))
         self.run_case(self.make_case("L", 12))
 
-    def test_32i(self):
+    def test_32i(self) -> None:
         self.run_case(self.make_case("I", 12))
         self.run_case(self.make_case("I", 0x7FFFFFFF))
         self.run_case(self.make_case("I", -12))
         self.run_case(self.make_case("I", -1 << 31))
 
-    def test_32f(self):
+    def test_32f(self) -> None:
         self.run_case(self.make_case("F", 1))
         self.run_case(self.make_case("F", 3.40282306074e38))
         self.run_case(self.make_case("F", 1.175494e-38))
@@ -264,9 +276,10 @@ class TestCoreResampleConsistency:
 
 
 class TestCoreResampleAlphaCorrect:
-    def make_levels_case(self, mode):
+    def make_levels_case(self, mode: str) -> Image.Image:
         i = Image.new(mode, (256, 16))
         px = i.load()
+        assert px is not None
         for y in range(i.size[1]):
             for x in range(i.size[0]):
                 pix = [x] * len(mode)
@@ -274,17 +287,22 @@ class TestCoreResampleAlphaCorrect:
                 px[x, y] = tuple(pix)
         return i
 
-    def run_levels_case(self, i):
+    def run_levels_case(self, i: Image.Image) -> None:
         px = i.load()
+        assert px is not None
         for y in range(i.size[1]):
-            used_colors = {px[x, y][0] for x in range(i.size[0])}
+            used_colors = set()
+            for x in range(i.size[0]):
+                value = px[x, y]
+                assert isinstance(value, tuple)
+                used_colors.add(value[0])
             assert 256 == len(used_colors), (
                 "All colors should be present in resized image. "
-                f"Only {len(used_colors)} on {y} line."
+                f"Only {len(used_colors)} on line {y}."
             )
 
     @pytest.mark.xfail(reason="Current implementation isn't precise enough")
-    def test_levels_rgba(self):
+    def test_levels_rgba(self) -> None:
         case = self.make_levels_case("RGBA")
         self.run_levels_case(case.resize((512, 32), Image.Resampling.BOX))
         self.run_levels_case(case.resize((512, 32), Image.Resampling.BILINEAR))
@@ -293,7 +311,7 @@ class TestCoreResampleAlphaCorrect:
         self.run_levels_case(case.resize((512, 32), Image.Resampling.LANCZOS))
 
     @pytest.mark.xfail(reason="Current implementation isn't precise enough")
-    def test_levels_la(self):
+    def test_levels_la(self) -> None:
         case = self.make_levels_case("LA")
         self.run_levels_case(case.resize((512, 32), Image.Resampling.BOX))
         self.run_levels_case(case.resize((512, 32), Image.Resampling.BILINEAR))
@@ -301,9 +319,12 @@ class TestCoreResampleAlphaCorrect:
         self.run_levels_case(case.resize((512, 32), Image.Resampling.BICUBIC))
         self.run_levels_case(case.resize((512, 32), Image.Resampling.LANCZOS))
 
-    def make_dirty_case(self, mode, clean_pixel, dirty_pixel):
+    def make_dirty_case(
+        self, mode: str, clean_pixel: tuple[int, ...], dirty_pixel: tuple[int, ...]
+    ) -> Image.Image:
         i = Image.new(mode, (64, 64), dirty_pixel)
         px = i.load()
+        assert px is not None
         xdiv4 = i.size[0] // 4
         ydiv4 = i.size[1] // 4
         for y in range(ydiv4 * 2):
@@ -311,18 +332,20 @@ class TestCoreResampleAlphaCorrect:
                 px[x + xdiv4, y + ydiv4] = clean_pixel
         return i
 
-    def run_dirty_case(self, i, clean_pixel):
+    def run_dirty_case(self, i: Image.Image, clean_pixel: tuple[int, ...]) -> None:
         px = i.load()
+        assert px is not None
         for y in range(i.size[1]):
             for x in range(i.size[0]):
-                if px[x, y][-1] != 0 and px[x, y][:-1] != clean_pixel:
+                value = px[x, y]
+                assert isinstance(value, tuple)
+                if value[-1] != 0 and value[:-1] != clean_pixel:
                     message = (
-                        f"pixel at ({x}, {y}) is different:\n"
-                        f"{px[x, y]}\n{clean_pixel}"
+                        f"pixel at ({x}, {y}) is different:\n{value}\n{clean_pixel}"
                     )
-                    assert px[x, y][:3] == clean_pixel, message
+                    assert value[:3] == clean_pixel, message
 
-    def test_dirty_pixels_rgba(self):
+    def test_dirty_pixels_rgba(self) -> None:
         case = self.make_dirty_case("RGBA", (255, 255, 0, 128), (0, 0, 255, 0))
         self.run_dirty_case(case.resize((20, 20), Image.Resampling.BOX), (255, 255, 0))
         self.run_dirty_case(
@@ -338,7 +361,7 @@ class TestCoreResampleAlphaCorrect:
             case.resize((20, 20), Image.Resampling.LANCZOS), (255, 255, 0)
         )
 
-    def test_dirty_pixels_la(self):
+    def test_dirty_pixels_la(self) -> None:
         case = self.make_dirty_case("LA", (255, 128), (0, 0))
         self.run_dirty_case(case.resize((20, 20), Image.Resampling.BOX), (255,))
         self.run_dirty_case(case.resize((20, 20), Image.Resampling.BILINEAR), (255,))
@@ -349,27 +372,27 @@ class TestCoreResampleAlphaCorrect:
 
 class TestCoreResamplePasses:
     @contextmanager
-    def count(self, diff):
+    def count(self, diff: int) -> Generator[None, None, None]:
         count = Image.core.get_stats()["new_count"]
         yield
         assert Image.core.get_stats()["new_count"] - count == diff
 
-    def test_horizontal(self):
+    def test_horizontal(self) -> None:
         im = hopper("L")
         with self.count(1):
             im.resize((im.size[0] - 10, im.size[1]), Image.Resampling.BILINEAR)
 
-    def test_vertical(self):
+    def test_vertical(self) -> None:
         im = hopper("L")
         with self.count(1):
             im.resize((im.size[0], im.size[1] - 10), Image.Resampling.BILINEAR)
 
-    def test_both(self):
+    def test_both(self) -> None:
         im = hopper("L")
         with self.count(2):
             im.resize((im.size[0] - 10, im.size[1] - 10), Image.Resampling.BILINEAR)
 
-    def test_box_horizontal(self):
+    def test_box_horizontal(self) -> None:
         im = hopper("L")
         box = (20, 0, im.size[0] - 20, im.size[1])
         with self.count(1):
@@ -379,7 +402,7 @@ class TestCoreResamplePasses:
             cropped = im.crop(box).resize(im.size, Image.Resampling.BILINEAR)
         assert_image_similar(with_box, cropped, 0.1)
 
-    def test_box_vertical(self):
+    def test_box_vertical(self) -> None:
         im = hopper("L")
         box = (0, 20, im.size[0], im.size[1] - 20)
         with self.count(1):
@@ -391,7 +414,7 @@ class TestCoreResamplePasses:
 
 
 class TestCoreResampleCoefficients:
-    def test_reduce(self):
+    def test_reduce(self) -> None:
         test_color = 254
 
         for size in range(400000, 400010, 2):
@@ -400,10 +423,11 @@ class TestCoreResampleCoefficients:
             draw.rectangle((0, 0, i.size[0] // 2 - 1, 0), test_color)
 
             px = i.resize((5, i.size[1]), Image.Resampling.BICUBIC).load()
+            assert px is not None
             if px[2, 0] != test_color // 2:
                 assert test_color // 2 == px[2, 0]
 
-    def test_nonzero_coefficients(self):
+    def test_non_zero_coefficients(self) -> None:
         # regression test for the wrong coefficients calculation
         # due to bug https://github.com/python-pillow/Pillow/issues/2161
         im = Image.new("RGBA", (1280, 1280), (0x20, 0x40, 0x60, 0xFF))
@@ -431,15 +455,15 @@ class TestCoreResampleBox:
             Image.Resampling.LANCZOS,
         ),
     )
-    def test_wrong_arguments(self, resample):
+    def test_wrong_arguments(self, resample: Image.Resampling) -> None:
         im = hopper()
         im.resize((32, 32), resample, (0, 0, im.width, im.height))
         im.resize((32, 32), resample, (20, 20, im.width, im.height))
         im.resize((32, 32), resample, (20, 20, 20, 100))
         im.resize((32, 32), resample, (20, 20, 100, 20))
 
-        with pytest.raises(TypeError, match="must be sequence of length 4"):
-            im.resize((32, 32), resample, (im.width, im.height))
+        with pytest.raises(TypeError, match="must be (sequence|tuple) of length 4"):
+            im.resize((32, 32), resample, (im.width, im.height))  # type: ignore[arg-type]
 
         with pytest.raises(ValueError, match="can't be negative"):
             im.resize((32, 32), resample, (-20, 20, 100, 100))
@@ -458,8 +482,12 @@ class TestCoreResampleBox:
         with pytest.raises(ValueError, match="can't exceed"):
             im.resize((32, 32), resample, (0, 0, im.width, im.height + 1))
 
-    def resize_tiled(self, im, dst_size, xtiles, ytiles):
-        def split_range(size, tiles):
+    def resize_tiled(
+        self, im: Image.Image, dst_size: tuple[int, int], xtiles: int, ytiles: int
+    ) -> Image.Image:
+        def split_range(
+            size: int, tiles: int
+        ) -> Generator[tuple[int, int], None, None]:
             scale = size / tiles
             for i in range(tiles):
                 yield int(round(scale * i)), int(round(scale * (i + 1)))
@@ -477,7 +505,7 @@ class TestCoreResampleBox:
     @mark_if_feature_version(
         pytest.mark.valgrind_known_error, "libjpeg_turbo", "2.0", reason="Known Failing"
     )
-    def test_tiles(self):
+    def test_tiles(self) -> None:
         with Image.open("Tests/images/flower.jpg") as im:
             assert im.size == (480, 360)
             dst_size = (251, 188)
@@ -490,7 +518,7 @@ class TestCoreResampleBox:
     @mark_if_feature_version(
         pytest.mark.valgrind_known_error, "libjpeg_turbo", "2.0", reason="Known Failing"
     )
-    def test_subsample(self):
+    def test_subsample(self) -> None:
         # This test shows advantages of the subpixel resizing
         # after supersampling (e.g. during JPEG decoding).
         with Image.open("Tests/images/flower.jpg") as im:
@@ -517,14 +545,14 @@ class TestCoreResampleBox:
     @pytest.mark.parametrize(
         "resample", (Image.Resampling.NEAREST, Image.Resampling.BILINEAR)
     )
-    def test_formats(self, mode, resample):
+    def test_formats(self, mode: str, resample: Image.Resampling) -> None:
         im = hopper(mode)
         box = (20, 20, im.size[0] - 20, im.size[1] - 20)
         with_box = im.resize((32, 32), resample, box)
         cropped = im.crop(box).resize((32, 32), resample)
         assert_image_similar(cropped, with_box, 0.4)
 
-    def test_passthrough(self):
+    def test_passthrough(self) -> None:
         # When no resize is required
         im = hopper()
 
@@ -538,7 +566,7 @@ class TestCoreResampleBox:
             assert res.size == size
             assert_image_equal(res, im.crop(box), f">>> {size} {box}")
 
-    def test_no_passthrough(self):
+    def test_no_passthrough(self) -> None:
         # When resize is required
         im = hopper()
 
@@ -557,7 +585,7 @@ class TestCoreResampleBox:
     @pytest.mark.parametrize(
         "flt", (Image.Resampling.NEAREST, Image.Resampling.BICUBIC)
     )
-    def test_skip_horizontal(self, flt):
+    def test_skip_horizontal(self, flt: Image.Resampling) -> None:
         # Can skip resize for one dimension
         im = hopper()
 
@@ -580,7 +608,7 @@ class TestCoreResampleBox:
     @pytest.mark.parametrize(
         "flt", (Image.Resampling.NEAREST, Image.Resampling.BICUBIC)
     )
-    def test_skip_vertical(self, flt):
+    def test_skip_vertical(self, flt: Image.Resampling) -> None:
         # Can skip resize for one dimension
         im = hopper()
 
