@@ -11,7 +11,6 @@ from pathlib import Path
 from typing import Any, BinaryIO
 
 import pytest
-from packaging.version import parse as parse_version
 
 from PIL import Image, ImageDraw, ImageFont, features
 from PIL._typing import StrOrBytesPath
@@ -20,6 +19,7 @@ from .helper import (
     assert_image_equal,
     assert_image_equal_tofile,
     assert_image_similar_tofile,
+    has_feature_version,
     is_win32,
     skip_unless_feature,
     skip_unless_feature_version,
@@ -493,6 +493,11 @@ def test_stroke_mask() -> None:
     assert mask.getpixel((42, 5)) == 255
 
 
+def test_load_invalid_file() -> None:
+    with pytest.raises(SyntaxError, match="Not a PILfont file"):
+        ImageFont.load("Tests/images/1_trns.png")
+
+
 def test_load_when_image_not_found() -> None:
     with tempfile.NamedTemporaryFile(delete=False) as tmp:
         pass
@@ -550,7 +555,7 @@ def test_default_font() -> None:
     draw.text((10, 60), txt, font=larger_default_font)
 
     # Assert
-    assert_image_equal_tofile(im, "Tests/images/default_font_freetype.png")
+    assert_image_similar_tofile(im, "Tests/images/default_font_freetype.png", 0.13)
 
 
 @pytest.mark.parametrize("mode", ("", "1", "RGBA"))
@@ -691,16 +696,6 @@ def test_complex_font_settings() -> None:
 
 
 def test_variation_get(font: ImageFont.FreeTypeFont) -> None:
-    version = features.version_module("freetype2")
-    assert version is not None
-    freetype = parse_version(version)
-    if freetype < parse_version("2.9.1"):
-        with pytest.raises(NotImplementedError):
-            font.get_variation_names()
-        with pytest.raises(NotImplementedError):
-            font.get_variation_axes()
-        return
-
     with pytest.raises(OSError):
         font.get_variation_names()
     with pytest.raises(OSError):
@@ -763,14 +758,6 @@ def _check_text(font: ImageFont.FreeTypeFont, path: str, epsilon: float) -> None
 
 
 def test_variation_set_by_name(font: ImageFont.FreeTypeFont) -> None:
-    version = features.version_module("freetype2")
-    assert version is not None
-    freetype = parse_version(version)
-    if freetype < parse_version("2.9.1"):
-        with pytest.raises(NotImplementedError):
-            font.set_variation_by_name("Bold")
-        return
-
     with pytest.raises(OSError):
         font.set_variation_by_name("Bold")
 
@@ -790,14 +777,6 @@ def test_variation_set_by_name(font: ImageFont.FreeTypeFont) -> None:
 
 
 def test_variation_set_by_axes(font: ImageFont.FreeTypeFont) -> None:
-    version = features.version_module("freetype2")
-    assert version is not None
-    freetype = parse_version(version)
-    if freetype < parse_version("2.9.1"):
-        with pytest.raises(NotImplementedError):
-            font.set_variation_by_axes([100])
-        return
-
     with pytest.raises(OSError):
         font.set_variation_by_axes([500, 50])
 
@@ -1082,7 +1061,10 @@ def test_colr(layout_engine: ImageFont.Layout) -> None:
 
     d.text((15, 5), "Bungee", font=font, embedded_color=True)
 
-    assert_image_similar_tofile(im, "Tests/images/colr_bungee.png", 21)
+    if has_feature_version("freetype2", "2.14.0"):
+        assert_image_similar_tofile(im, "Tests/images/colr_bungee.png", 6.1)
+    else:
+        assert_image_similar_tofile(im, "Tests/images/colr_bungee_older.png", 21)
 
 
 @skip_unless_feature_version("freetype2", "2.10.0")
@@ -1098,7 +1080,7 @@ def test_colr_mask(layout_engine: ImageFont.Layout) -> None:
 
     d.text((15, 5), "Bungee", "black", font=font)
 
-    assert_image_similar_tofile(im, "Tests/images/colr_bungee_mask.png", 22)
+    assert_image_similar_tofile(im, "Tests/images/colr_bungee_mask.png", 14.1)
 
 
 def test_woff2(layout_engine: ImageFont.Layout) -> None:
@@ -1209,15 +1191,3 @@ def test_invalid_truetype_sizes_raise_valueerror(
 ) -> None:
     with pytest.raises(ValueError):
         ImageFont.truetype(FONT_PATH, size, layout_engine=layout_engine)
-
-
-def test_freetype_deprecation(monkeypatch: pytest.MonkeyPatch) -> None:
-    # Arrange: mock features.version_module to return fake FreeType version
-    def fake_version_module(module: str) -> str:
-        return "2.9.0"
-
-    monkeypatch.setattr(features, "version_module", fake_version_module)
-
-    # Act / Assert
-    with pytest.warns(DeprecationWarning, match="FreeType 2.9.0"):
-        ImageFont.truetype(FONT_PATH, FONT_SIZE)
