@@ -1,4 +1,5 @@
 from __future__ import annotations
+
 import pytest
 
 from PIL import Image, ImageStat
@@ -6,7 +7,7 @@ from PIL import Image, ImageStat
 from .helper import hopper
 
 
-def test_sanity():
+def test_sanity() -> None:
     im = hopper()
 
     st = ImageStat.Stat(im)
@@ -24,13 +25,13 @@ def test_sanity():
     st.stddev
 
     with pytest.raises(AttributeError):
-        st.spam()
+        st.spam()  # type: ignore[attr-defined]
 
     with pytest.raises(TypeError):
-        ImageStat.Stat(1)
+        ImageStat.Stat(1)  # type: ignore[arg-type]
 
 
-def test_hopper():
+def test_hopper() -> None:
     im = hopper()
 
     st = ImageStat.Stat(im)
@@ -43,7 +44,7 @@ def test_hopper():
     assert st.sum[2] == 1563008
 
 
-def test_constant():
+def test_constant() -> None:
     im = Image.new("L", (128, 128), 128)
 
     st = ImageStat.Stat(im)
@@ -56,3 +57,13 @@ def test_constant():
     assert st.rms[0] == 128
     assert st.var[0] == 0
     assert st.stddev[0] == 0
+
+
+def test_zero_count() -> None:
+    im = Image.new("L", (0, 0))
+
+    st = ImageStat.Stat(im)
+
+    assert st.mean == [0]
+    assert st.rms == [0]
+    assert st.var == [0]
