@@ -1,10 +1,11 @@
 from __future__ import annotations
+
 import pytest
 
 from PIL import Image
 
 
-def test_setmode():
+def test_setmode() -> None:
     im = Image.new("L", (1, 1), 255)
     im.im.setmode("1")
     assert im.im.getpixel((0, 0)) == 255
