@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import warnings
-from typing import TYPE_CHECKING
 
 import pytest
 
@@ -9,6 +8,7 @@ from PIL import Image, _typing
 
 from .helper import assert_deep_equal, assert_image, hopper, skip_unless_feature
 
+TYPE_CHECKING = False
 if TYPE_CHECKING:
     import numpy
     import numpy.typing as npt
@@ -28,15 +28,13 @@ def test_numpy_to_image() -> None:
             a = numpy.array(data, dtype=dtype)
             a.shape = TEST_IMAGE_SIZE
             i = Image.fromarray(a)
-            if list(i.getdata()) != data:
-                print("data mismatch for", dtype)
+            assert list(i.getdata()) == data
         else:
             data = list(range(100))
             a = numpy.array([[x] * bands for x in data], dtype=dtype)
             a.shape = TEST_IMAGE_SIZE[0], TEST_IMAGE_SIZE[1], bands
             i = Image.fromarray(a)
-            if list(i.getchannel(0).getdata()) != list(range(100)):
-                print("data mismatch for", dtype)
+            assert list(i.getchannel(0).getdata()) == list(range(100))
         return i
 
     # Check supported 1-bit integer formats
@@ -141,9 +139,7 @@ def test_save_tiff_uint16() -> None:
     a.shape = TEST_IMAGE_SIZE
     img = Image.fromarray(a)
 
-    img_px = img.load()
-    assert img_px is not None
-    assert img_px[0, 0] == pixel_value
+    assert img.getpixel((0, 0)) == pixel_value
 
 
 @pytest.mark.parametrize(
