@@ -15,18 +15,15 @@
  * See the README file for details on usage and redistribution.
  */
 
-
 #include "Imaging.h"
 
-
 static Imaging
-_copy(Imaging imOut, Imaging imIn)
-{
+_copy(Imaging imOut, Imaging imIn) {
     ImagingSectionCookie cookie;
     int y;
 
     if (!imIn) {
-        return (Imaging) ImagingError_ValueError(NULL);
+        return (Imaging)ImagingError_ValueError(NULL);
     }
 
     imOut = ImagingNew2Dirty(imIn->mode, imOut, imIn);
@@ -50,13 +47,11 @@ _copy(Imaging imOut, Imaging imIn)
 }
 
 Imaging
-ImagingCopy(Imaging imIn)
-{
+ImagingCopy(Imaging imIn) {
     return _copy(NULL, imIn);
 }
 
 Imaging
-ImagingCopy2(Imaging imOut, Imaging imIn)
-{
+ImagingCopy2(Imaging imOut, Imaging imIn) {
     return _copy(imOut, imIn);
 }
