@@ -11,6 +11,7 @@
  */
 
 #include "ImPlatform.h"
+#include "Mode.h"
 
 #if defined(__cplusplus)
 extern "C" {
@@ -20,6 +21,8 @@ extern "C" {
 #define M_PI 3.1415926535897932384626433832795
 #endif
 
+#include "Arrow.h"
+
 /* -------------------------------------------------------------------- */
 
 /*
@@ -60,8 +63,8 @@ typedef struct ImagingHistogramInstance *ImagingHistogram;
 typedef struct ImagingOutlineInstance *ImagingOutline;
 typedef struct ImagingPaletteInstance *ImagingPalette;
 
-/* handle magics (used with PyCObject). */
-#define IMAGING_MAGIC "PIL Imaging"
+/* handle magics (used with PyCapsule). */
+#define IMAGING_MAGIC "Pillow Imaging"
 
 /* pixel types */
 #define IMAGING_TYPE_UINT8 0
@@ -69,9 +72,6 @@ typedef struct ImagingPaletteInstance *ImagingPalette;
 #define IMAGING_TYPE_FLOAT32 2
 #define IMAGING_TYPE_SPECIAL 3 /* check mode for details */
 
-#define IMAGING_MODE_LENGTH \
-    6 + 1 /* Band names ("1", "L", "P", "RGB", "RGBA", "CMYK", "YCbCr", "BGR;xy") */
-
 typedef struct {
     char *ptr;
     int size;
@@ -79,12 +79,11 @@ typedef struct {
 
 struct ImagingMemoryInstance {
     /* Format */
-    char mode[IMAGING_MODE_LENGTH]; /* Band names ("1", "L", "P", "RGB", "RGBA", "CMYK",
-                                       "YCbCr", "BGR;xy") */
-    int type;                       /* Data type (IMAGING_TYPE_*) */
-    int depth;                      /* Depth (ignored in this version) */
-    int bands;                      /* Number of bands (1, 2, 3, or 4) */
-    int xsize;                      /* Image dimension. */
+    ModeID mode; /* Image mode (IMAGING_MODE_*) */
+    int type;    /* Data type (IMAGING_TYPE_*) */
+    int depth;   /* Depth (ignored in this version) */
+    int bands;   /* Number of bands (1, 2, 3, or 4) */
+    int xsize;   /* Image dimension. */
     int ysize;
 
     /* Colour palette (for "P" images only) */
@@ -104,34 +103,49 @@ struct ImagingMemoryInstance {
 
     /* Virtual methods */
     void (*destroy)(Imaging im);
+
+    /* arrow */
+    int refcount;              /* Number of arrow arrays that have been allocated */
+    char band_names[4][3];     /* names of bands, max 2 char + null terminator */
+    char arrow_band_format[2]; /* single character + null terminator */
+
+    int read_only; /* flag for read-only. set for arrow borrowed arrays */
+    PyObject *arrow_array_capsule; /* upstream arrow array source */
+
+    int blocks_count;    /* Number of blocks that have been allocated */
+    int lines_per_block; /* Number of lines in a block have been allocated */
+
+#ifdef Py_GIL_DISABLED
+    PyMutex mutex;
+#endif
 };
 
 #define IMAGING_PIXEL_1(im, x, y) ((im)->image8[(y)][(x)])
 #define IMAGING_PIXEL_L(im, x, y) ((im)->image8[(y)][(x)])
-#define IMAGING_PIXEL_LA(im, x, y) ((im)->image[(y)][(x)*4])
+#define IMAGING_PIXEL_LA(im, x, y) ((im)->image[(y)][(x) * 4])
 #define IMAGING_PIXEL_P(im, x, y) ((im)->image8[(y)][(x)])
-#define IMAGING_PIXEL_PA(im, x, y) ((im)->image[(y)][(x)*4])
+#define IMAGING_PIXEL_PA(im, x, y) ((im)->image[(y)][(x) * 4])
 #define IMAGING_PIXEL_I(im, x, y) ((im)->image32[(y)][(x)])
 #define IMAGING_PIXEL_F(im, x, y) (((FLOAT32 *)(im)->image32[y])[x])
-#define IMAGING_PIXEL_RGB(im, x, y) ((im)->image[(y)][(x)*4])
-#define IMAGING_PIXEL_RGBA(im, x, y) ((im)->image[(y)][(x)*4])
-#define IMAGING_PIXEL_CMYK(im, x, y) ((im)->image[(y)][(x)*4])
-#define IMAGING_PIXEL_YCbCr(im, x, y) ((im)->image[(y)][(x)*4])
+#define IMAGING_PIXEL_RGB(im, x, y) ((im)->image[(y)][(x) * 4])
+#define IMAGING_PIXEL_RGBA(im, x, y) ((im)->image[(y)][(x) * 4])
+#define IMAGING_PIXEL_CMYK(im, x, y) ((im)->image[(y)][(x) * 4])
+#define IMAGING_PIXEL_YCbCr(im, x, y) ((im)->image[(y)][(x) * 4])
 
 #define IMAGING_PIXEL_UINT8(im, x, y) ((im)->image8[(y)][(x)])
 #define IMAGING_PIXEL_INT32(im, x, y) ((im)->image32[(y)][(x)])
 #define IMAGING_PIXEL_FLOAT32(im, x, y) (((FLOAT32 *)(im)->image32[y])[x])
 
 struct ImagingAccessInstance {
-    const char *mode;
+    ModeID mode;
     void (*get_pixel)(Imaging im, int x, int y, void *pixel);
     void (*put_pixel)(Imaging im, int x, int y, const void *pixel);
 };
 
 struct ImagingHistogramInstance {
     /* Format */
-    char mode[IMAGING_MODE_LENGTH]; /* Band names (of corresponding source image) */
-    int bands;                      /* Number of bands (1, 3, or 4) */
+    ModeID mode; /* Mode ID of corresponding source image */
+    int bands;   /* Number of bands (1, 2, 3, or 4) */
 
     /* Data */
     long *histogram; /* Histogram (bands*256 longs) */
@@ -139,7 +153,7 @@ struct ImagingHistogramInstance {
 
 struct ImagingPaletteInstance {
     /* Format */
-    char mode[IMAGING_MODE_LENGTH]; /* Band names */
+    ModeID mode;
 
     /* Data */
     int size;
@@ -161,7 +175,11 @@ typedef struct ImagingMemoryArena {
     int stats_reallocated_blocks; /* Number of blocks which were actually reallocated
                                      after retrieving */
     int stats_freed_blocks;       /* Number of freed blocks */
-} * ImagingMemoryArena;
+    int use_block_allocator;      /* don't use arena, use block allocator */
+#ifdef Py_GIL_DISABLED
+    PyMutex mutex;
+#endif
+} *ImagingMemoryArena;
 
 /* Objects */
 /* ------- */
@@ -171,23 +189,34 @@ extern int
 ImagingMemorySetBlocksMax(ImagingMemoryArena arena, int blocks_max);
 extern void
 ImagingMemoryClearCache(ImagingMemoryArena arena, int new_size);
+extern void
+ImagingMemorySetBlockAllocator(ImagingMemoryArena arena, int use_block_allocator);
 
 extern Imaging
-ImagingNew(const char *mode, int xsize, int ysize);
+ImagingNew(ModeID mode, int xsize, int ysize);
 extern Imaging
-ImagingNewDirty(const char *mode, int xsize, int ysize);
+ImagingNewDirty(ModeID mode, int xsize, int ysize);
 extern Imaging
-ImagingNew2Dirty(const char *mode, Imaging imOut, Imaging imIn);
+ImagingNew2Dirty(ModeID mode, Imaging imOut, Imaging imIn);
 extern void
 ImagingDelete(Imaging im);
 
 extern Imaging
-ImagingNewBlock(const char *mode, int xsize, int ysize);
+ImagingNewBlock(ModeID mode, int xsize, int ysize);
 
 extern Imaging
-ImagingNewPrologue(const char *mode, int xsize, int ysize);
+ImagingNewArrow(
+    const ModeID mode,
+    int xsize,
+    int ysize,
+    PyObject *schema_capsule,
+    PyObject *array_capsule
+);
+
 extern Imaging
-ImagingNewPrologueSubtype(const char *mode, int xsize, int ysize, int structure_size);
+ImagingNewPrologue(ModeID mode, int xsize, int ysize);
+extern Imaging
+ImagingNewPrologueSubtype(ModeID mode, int xsize, int ysize, int structure_size);
 
 extern void
 ImagingCopyPalette(Imaging destination, Imaging source);
@@ -195,8 +224,6 @@ ImagingCopyPalette(Imaging destination, Imaging source);
 extern void
 ImagingHistogramDelete(ImagingHistogram histogram);
 
-extern void
-ImagingAccessInit(void);
 extern ImagingAccess
 ImagingAccessNew(Imaging im);
 extern void
@@ -204,7 +231,7 @@ _ImagingAccessDelete(Imaging im, ImagingAccess access);
 #define ImagingAccessDelete(im, access) /* nop, for now */
 
 extern ImagingPalette
-ImagingPaletteNew(const char *mode);
+ImagingPaletteNew(ModeID mode);
 extern ImagingPalette
 ImagingPaletteNewBrowser(void);
 extern ImagingPalette
@@ -238,8 +265,6 @@ ImagingSectionLeave(ImagingSectionCookie *cookie);
 /* Exceptions */
 /* ---------- */
 
-extern void *
-ImagingError_OSError(void);
 extern void *
 ImagingError_MemoryError(void);
 extern void *
@@ -248,8 +273,6 @@ extern void *
 ImagingError_Mismatch(void); /* maps to ValueError by default */
 extern void *
 ImagingError_ValueError(const char *message);
-extern void
-ImagingError_Clear(void);
 
 /* Transform callbacks */
 /* ------------------- */
@@ -280,28 +303,29 @@ ImagingBlend(Imaging imIn1, Imaging imIn2, float alpha);
 extern Imaging
 ImagingCopy(Imaging im);
 extern Imaging
-ImagingConvert(Imaging im, const char *mode, ImagingPalette palette, int dither);
+ImagingConvert(Imaging im, ModeID mode, ImagingPalette palette, int dither);
 extern Imaging
-ImagingConvertInPlace(Imaging im, const char *mode);
+ImagingConvertInPlace(Imaging im, ModeID mode);
 extern Imaging
-ImagingConvertMatrix(Imaging im, const char *mode, float m[]);
+ImagingConvertMatrix(Imaging im, ModeID mode, float m[]);
 extern Imaging
-ImagingConvertTransparent(Imaging im, const char *mode, int r, int g, int b);
+ImagingConvertTransparent(Imaging im, ModeID mode, int r, int g, int b);
 extern Imaging
 ImagingCrop(Imaging im, int x0, int y0, int x1, int y1);
 extern Imaging
-ImagingExpand(Imaging im, int x, int y, int mode);
+ImagingExpand(Imaging im, int x, int y);
 extern Imaging
 ImagingFill(Imaging im, const void *ink);
 extern int
 ImagingFill2(
-    Imaging into, const void *ink, Imaging mask, int x0, int y0, int x1, int y1);
+    Imaging into, const void *ink, Imaging mask, int x0, int y0, int x1, int y1
+);
 extern Imaging
 ImagingFillBand(Imaging im, int band, int color);
 extern Imaging
-ImagingFillLinearGradient(const char *mode);
+ImagingFillLinearGradient(ModeID mode);
 extern Imaging
-ImagingFillRadialGradient(const char *mode);
+ImagingFillRadialGradient(ModeID mode);
 extern Imaging
 ImagingFilter(Imaging im, int xsize, int ysize, const FLOAT32 *kernel, FLOAT32 offset);
 extern Imaging
@@ -309,15 +333,17 @@ ImagingFlipLeftRight(Imaging imOut, Imaging imIn);
 extern Imaging
 ImagingFlipTopBottom(Imaging imOut, Imaging imIn);
 extern Imaging
-ImagingGaussianBlur(Imaging imOut, Imaging imIn, float radius, int passes);
+ImagingGaussianBlur(
+    Imaging imOut, Imaging imIn, float xradius, float yradius, int passes
+);
 extern Imaging
 ImagingGetBand(Imaging im, int band);
 extern Imaging
-ImagingMerge(const char *mode, Imaging bands[4]);
+ImagingMerge(ModeID mode, Imaging bands[4]);
 extern int
 ImagingSplit(Imaging im, Imaging bands[4]);
 extern int
-ImagingGetBBox(Imaging im, int bbox[4]);
+ImagingGetBBox(Imaging im, int bbox[4], int alpha_only);
 typedef struct {
     int x, y;
     INT32 count;
@@ -340,7 +366,7 @@ ImagingOffset(Imaging im, int xoffset, int yoffset);
 extern int
 ImagingPaste(Imaging into, Imaging im, Imaging mask, int x0, int y0, int x1, int y1);
 extern Imaging
-ImagingPoint(Imaging im, const char *tablemode, const void *table);
+ImagingPoint(Imaging im, ModeID tablemode, const void *table);
 extern Imaging
 ImagingPointTransform(Imaging imIn, double scale, double offset);
 extern Imaging
@@ -372,11 +398,12 @@ ImagingTransform(
     int y1,
     double a[8],
     int filter,
-    int fill);
+    int fill
+);
 extern Imaging
 ImagingUnsharpMask(Imaging imOut, Imaging im, float radius, int percent, int threshold);
 extern Imaging
-ImagingBoxBlur(Imaging imOut, Imaging imIn, float radius, int n);
+ImagingBoxBlur(Imaging imOut, Imaging imIn, float xradius, float yradius, int n);
 extern Imaging
 ImagingColorLUT3D_linear(
     Imaging imOut,
@@ -385,7 +412,8 @@ ImagingColorLUT3D_linear(
     int size1D,
     int size2D,
     int size3D,
-    INT16 *table);
+    INT16 *table
+);
 
 extern Imaging
 ImagingCopy2(Imaging imOut, Imaging imIn);
@@ -439,7 +467,8 @@ ImagingDrawArc(
     float end,
     const void *ink,
     int width,
-    int op);
+    int op
+);
 extern int
 ImagingDrawBitmap(Imaging im, int x0, int y0, Imaging bitmap, const void *ink, int op);
 extern int
@@ -454,7 +483,8 @@ ImagingDrawChord(
     const void *ink,
     int fill,
     int width,
-    int op);
+    int op
+);
 extern int
 ImagingDrawEllipse(
     Imaging im,
@@ -465,12 +495,22 @@ ImagingDrawEllipse(
     const void *ink,
     int fill,
     int width,
-    int op);
+    int op
+);
 extern int
 ImagingDrawLine(Imaging im, int x0, int y0, int x1, int y1, const void *ink, int op);
 extern int
 ImagingDrawWideLine(
-    Imaging im, int x0, int y0, int x1, int y1, const void *ink, int width, int op);
+    Imaging im,
+    int x0,
+    int y0,
+    int x1,
+    int y1,
+    const void *ink,
+    int width,
+    int op,
+    Imaging mask
+);
 extern int
 ImagingDrawPieslice(
     Imaging im,
@@ -483,11 +523,21 @@ ImagingDrawPieslice(
     const void *ink,
     int fill,
     int width,
-    int op);
+    int op
+);
 extern int
 ImagingDrawPoint(Imaging im, int x, int y, const void *ink, int op);
 extern int
-ImagingDrawPolygon(Imaging im, int points, int *xy, const void *ink, int fill, int width, int op);
+ImagingDrawPolygon(
+    Imaging im,
+    int points,
+    int *xy,
+    const void *ink,
+    int fill,
+    int width,
+    int op,
+    Imaging mask
+);
 extern int
 ImagingDrawRectangle(
     Imaging im,
@@ -498,7 +548,8 @@ ImagingDrawRectangle(
     const void *ink,
     int fill,
     int width,
-    int op);
+    int op
+);
 
 /* Level 2 graphics (WORK IN PROGRESS) */
 extern ImagingOutline
@@ -508,7 +559,8 @@ ImagingOutlineDelete(ImagingOutline outline);
 
 extern int
 ImagingDrawOutline(
-    Imaging im, ImagingOutline outline, const void *ink, int fill, int op);
+    Imaging im, ImagingOutline outline, const void *ink, int fill, int op
+);
 
 extern int
 ImagingOutlineMove(ImagingOutline outline, float x, float y);
@@ -516,7 +568,8 @@ extern int
 ImagingOutlineLine(ImagingOutline outline, float x, float y);
 extern int
 ImagingOutlineCurve(
-    ImagingOutline outline, float x1, float y1, float x2, float y2, float x3, float y3);
+    ImagingOutline outline, float x1, float y1, float x2, float y2, float x3, float y3
+);
 extern int
 ImagingOutlineTransform(ImagingOutline outline, double a[6]);
 
@@ -543,11 +596,14 @@ ImagingSavePPM(Imaging im, const char *filename);
 /* Codecs */
 typedef struct ImagingCodecStateInstance *ImagingCodecState;
 typedef int (*ImagingCodec)(
-    Imaging im, ImagingCodecState state, UINT8 *buffer, int bytes);
+    Imaging im, ImagingCodecState state, UINT8 *buffer, int bytes
+);
 
 extern int
 ImagingBcnDecode(Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
 extern int
+ImagingBcnEncode(Imaging im, ImagingCodecState state, UINT8 *buffer, int bytes);
+extern int
 ImagingBitDecode(Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
 extern int
 ImagingEpsEncode(Imaging im, ImagingCodecState state, UINT8 *buffer, int bytes);
@@ -573,7 +629,8 @@ ImagingJpegEncode(Imaging im, ImagingCodecState state, UINT8 *buffer, int bytes)
 #ifdef HAVE_OPENJPEG
 extern int
 ImagingJpeg2KDecode(
-    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
+    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes
+);
 extern int
 ImagingJpeg2KDecodeCleanup(ImagingCodecState state);
 extern int
@@ -584,19 +641,17 @@ ImagingJpeg2KEncodeCleanup(ImagingCodecState state);
 #ifdef HAVE_LIBTIFF
 extern int
 ImagingLibTiffDecode(
-    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
+    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes
+);
 extern int
 ImagingLibTiffEncode(Imaging im, ImagingCodecState state, UINT8 *buffer, int bytes);
 #endif
-#ifdef HAVE_LIBMPEG
-extern int
-ImagingMpegDecode(Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
-#endif
 extern int
 ImagingMspDecode(Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
 extern int
 ImagingPackbitsDecode(
-    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
+    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes
+);
 extern int
 ImagingPcdDecode(Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
 extern int
@@ -609,13 +664,16 @@ extern int
 ImagingRawEncode(Imaging im, ImagingCodecState state, UINT8 *buffer, int bytes);
 extern int
 ImagingSgiRleDecode(
-    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
+    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes
+);
 extern int
 ImagingSunRleDecode(
-    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
+    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes
+);
 extern int
 ImagingTgaRleDecode(
-    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes);
+    Imaging im, ImagingCodecState state, UINT8 *buffer, Py_ssize_t bytes
+);
 extern int
 ImagingTgaRleEncode(Imaging im, ImagingCodecState state, UINT8 *buffer, int bytes);
 extern int
@@ -649,9 +707,9 @@ extern void
 ImagingConvertYCbCr2RGB(UINT8 *out, const UINT8 *in, int pixels);
 
 extern ImagingShuffler
-ImagingFindUnpacker(const char *mode, const char *rawmode, int *bits_out);
+ImagingFindUnpacker(ModeID mode, RawModeID rawmode, int *bits_out);
 extern ImagingShuffler
-ImagingFindPacker(const char *mode, const char *rawmode, int *bits_out);
+ImagingFindPacker(ModeID mode, RawModeID rawmode, int *bits_out);
 
 struct ImagingCodecStateInstance {
     int count;
@@ -677,6 +735,13 @@ _imaging_seek_pyFd(PyObject *fd, Py_ssize_t offset, int whence);
 extern Py_ssize_t
 _imaging_tell_pyFd(PyObject *fd);
 
+/* Arrow */
+
+extern int
+export_imaging_array(Imaging im, struct ArrowArray *array);
+extern int
+export_imaging_schema(Imaging im, struct ArrowSchema *schema);
+
 /* Errcodes */
 #define IMAGING_CODEC_END 1
 #define IMAGING_CODEC_OVERRUN -1
@@ -684,10 +749,21 @@ _imaging_tell_pyFd(PyObject *fd);
 #define IMAGING_CODEC_UNKNOWN -3
 #define IMAGING_CODEC_CONFIG -8
 #define IMAGING_CODEC_MEMORY -9
+#define IMAGING_ARROW_INCOMPATIBLE_MODE -10
+#define IMAGING_ARROW_MEMORY_LAYOUT -11
 
 #include "ImagingUtils.h"
 extern UINT8 *clip8_lookups;
 
+/* Mutex lock/unlock helpers */
+#ifdef Py_GIL_DISABLED
+#define MUTEX_LOCK(m) PyMutex_Lock(m)
+#define MUTEX_UNLOCK(m) PyMutex_Unlock(m)
+#else
+#define MUTEX_LOCK(m)
+#define MUTEX_UNLOCK(m)
+#endif
+
 #if defined(__cplusplus)
 }
 #endif
