@@ -23,6 +23,18 @@
 
 #include "Imaging.h"
 
+#define PREPARE_PASTE_LOOP()        \
+    int y, y_end, offset;           \
+    if (imOut == imIn && dy > sy) { \
+        y = ysize - 1;              \
+        y_end = -1;                 \
+        offset = -1;                \
+    } else {                        \
+        y = 0;                      \
+        y_end = ysize;              \
+        offset = 1;                 \
+    }
+
 static inline void
 paste(
     Imaging imOut,
@@ -37,14 +49,13 @@ paste(
 ) {
     /* paste opaque region */
 
-    int y;
-
     dx *= pixelsize;
     sx *= pixelsize;
 
     xsize *= pixelsize;
 
-    for (y = 0; y < ysize; y++) {
+    PREPARE_PASTE_LOOP();
+    for (; y != y_end; y += offset) {
         memcpy(imOut->image[y + dy] + dx, imIn->image[y + sy] + sx, xsize);
     }
 }
@@ -64,12 +75,13 @@ paste_mask_1(
 ) {
     /* paste with mode "1" mask */
 
-    int x, y;
+    int x;
 
+    PREPARE_PASTE_LOOP();
     if (imOut->image8) {
-        int in_i16 = strncmp(imIn->mode, "I;16", 4) == 0;
-        int out_i16 = strncmp(imOut->mode, "I;16", 4) == 0;
-        for (y = 0; y < ysize; y++) {
+        int in_i16 = isModeI16(imIn->mode);
+        int out_i16 = isModeI16(imOut->mode);
+        for (; y != y_end; y += offset) {
             UINT8 *out = imOut->image8[y + dy] + dx;
             if (out_i16) {
                 out += dx;
@@ -97,7 +109,7 @@ paste_mask_1(
         }
 
     } else {
-        for (y = 0; y < ysize; y++) {
+        for (; y != y_end; y += offset) {
             INT32 *out = imOut->image32[y + dy] + dx;
             INT32 *in = imIn->image32[y + sy] + sx;
             UINT8 *mask = imMask->image8[y + sy] + sx;
@@ -126,11 +138,12 @@ paste_mask_L(
 ) {
     /* paste with mode "L" matte */
 
-    int x, y;
+    int x;
     unsigned int tmp1;
 
+    PREPARE_PASTE_LOOP();
     if (imOut->image8) {
-        for (y = 0; y < ysize; y++) {
+        for (; y != y_end; y += offset) {
             UINT8 *out = imOut->image8[y + dy] + dx;
             UINT8 *in = imIn->image8[y + sy] + sx;
             UINT8 *mask = imMask->image8[y + sy] + sx;
@@ -141,7 +154,7 @@ paste_mask_L(
         }
 
     } else {
-        for (y = 0; y < ysize; y++) {
+        for (; y != y_end; y += offset) {
             UINT8 *out = (UINT8 *)(imOut->image32[y + dy] + dx);
             UINT8 *in = (UINT8 *)(imIn->image32[y + sy] + sx);
             UINT8 *mask = (UINT8 *)(imMask->image8[y + sy] + sx);
@@ -174,11 +187,12 @@ paste_mask_RGBA(
 ) {
     /* paste with mode "RGBA" matte */
 
-    int x, y;
+    int x;
     unsigned int tmp1;
 
+    PREPARE_PASTE_LOOP();
     if (imOut->image8) {
-        for (y = 0; y < ysize; y++) {
+        for (; y != y_end; y += offset) {
             UINT8 *out = imOut->image8[y + dy] + dx;
             UINT8 *in = imIn->image8[y + sy] + sx;
             UINT8 *mask = (UINT8 *)imMask->image[y + sy] + sx * 4 + 3;
@@ -189,7 +203,7 @@ paste_mask_RGBA(
         }
 
     } else {
-        for (y = 0; y < ysize; y++) {
+        for (; y != y_end; y += offset) {
             UINT8 *out = (UINT8 *)(imOut->image32[y + dy] + dx);
             UINT8 *in = (UINT8 *)(imIn->image32[y + sy] + sx);
             UINT8 *mask = (UINT8 *)(imMask->image32[y + sy] + sx);
@@ -222,11 +236,12 @@ paste_mask_RGBa(
 ) {
     /* paste with mode "RGBa" matte */
 
-    int x, y;
+    int x;
     unsigned int tmp1;
 
+    PREPARE_PASTE_LOOP();
     if (imOut->image8) {
-        for (y = 0; y < ysize; y++) {
+        for (; y != y_end; y += offset) {
             UINT8 *out = imOut->image8[y + dy] + dx;
             UINT8 *in = imIn->image8[y + sy] + sx;
             UINT8 *mask = (UINT8 *)imMask->image[y + sy] + sx * 4 + 3;
@@ -237,7 +252,7 @@ paste_mask_RGBa(
         }
 
     } else {
-        for (y = 0; y < ysize; y++) {
+        for (; y != y_end; y += offset) {
             UINT8 *out = (UINT8 *)(imOut->image32[y + dy] + dx);
             UINT8 *in = (UINT8 *)(imIn->image32[y + sy] + sx);
             UINT8 *mask = (UINT8 *)(imMask->image32[y + sy] + sx);
@@ -307,31 +322,26 @@ ImagingPaste(
         ImagingSectionEnter(&cookie);
         paste(imOut, imIn, dx0, dy0, sx0, sy0, xsize, ysize, pixelsize);
         ImagingSectionLeave(&cookie);
-
-    } else if (strcmp(imMask->mode, "1") == 0) {
+    } else if (imMask->mode == IMAGING_MODE_1) {
         ImagingSectionEnter(&cookie);
         paste_mask_1(imOut, imIn, imMask, dx0, dy0, sx0, sy0, xsize, ysize, pixelsize);
         ImagingSectionLeave(&cookie);
-
-    } else if (strcmp(imMask->mode, "L") == 0) {
+    } else if (imMask->mode == IMAGING_MODE_L) {
         ImagingSectionEnter(&cookie);
         paste_mask_L(imOut, imIn, imMask, dx0, dy0, sx0, sy0, xsize, ysize, pixelsize);
         ImagingSectionLeave(&cookie);
-
-    } else if (strcmp(imMask->mode, "LA") == 0 || strcmp(imMask->mode, "RGBA") == 0) {
+    } else if (imMask->mode == IMAGING_MODE_LA || imMask->mode == IMAGING_MODE_RGBA) {
         ImagingSectionEnter(&cookie);
         paste_mask_RGBA(
             imOut, imIn, imMask, dx0, dy0, sx0, sy0, xsize, ysize, pixelsize
         );
         ImagingSectionLeave(&cookie);
-
-    } else if (strcmp(imMask->mode, "RGBa") == 0) {
+    } else if (imMask->mode == IMAGING_MODE_RGBa) {
         ImagingSectionEnter(&cookie);
         paste_mask_RGBa(
             imOut, imIn, imMask, dx0, dy0, sx0, sy0, xsize, ysize, pixelsize
         );
         ImagingSectionLeave(&cookie);
-
     } else {
         (void)ImagingError_ValueError("bad transparency mask");
         return -1;
@@ -437,7 +447,7 @@ fill_mask_L(
     unsigned int tmp1;
 
     if (imOut->image8) {
-        int i16 = strncmp(imOut->mode, "I;16", 4) == 0;
+        int i16 = isModeI16(imOut->mode);
         for (y = 0; y < ysize; y++) {
             UINT8 *out = imOut->image8[y + dy] + dx;
             if (i16) {
@@ -456,9 +466,9 @@ fill_mask_L(
 
     } else {
         int alpha_channel =
-            strcmp(imOut->mode, "RGBa") == 0 || strcmp(imOut->mode, "RGBA") == 0 ||
-            strcmp(imOut->mode, "La") == 0 || strcmp(imOut->mode, "LA") == 0 ||
-            strcmp(imOut->mode, "PA") == 0;
+            imOut->mode == IMAGING_MODE_RGBa || imOut->mode == IMAGING_MODE_RGBA ||
+            imOut->mode == IMAGING_MODE_La || imOut->mode == IMAGING_MODE_LA ||
+            imOut->mode == IMAGING_MODE_PA;
         for (y = 0; y < ysize; y++) {
             UINT8 *out = (UINT8 *)imOut->image[y + dy] + dx * pixelsize;
             UINT8 *mask = (UINT8 *)imMask->image[y + sy] + sx;
@@ -617,27 +627,22 @@ ImagingFill2(
         ImagingSectionEnter(&cookie);
         fill(imOut, ink, dx0, dy0, xsize, ysize, pixelsize);
         ImagingSectionLeave(&cookie);
-
-    } else if (strcmp(imMask->mode, "1") == 0) {
+    } else if (imMask->mode == IMAGING_MODE_1) {
         ImagingSectionEnter(&cookie);
         fill_mask_1(imOut, ink, imMask, dx0, dy0, sx0, sy0, xsize, ysize, pixelsize);
         ImagingSectionLeave(&cookie);
-
-    } else if (strcmp(imMask->mode, "L") == 0) {
+    } else if (imMask->mode == IMAGING_MODE_L) {
         ImagingSectionEnter(&cookie);
         fill_mask_L(imOut, ink, imMask, dx0, dy0, sx0, sy0, xsize, ysize, pixelsize);
         ImagingSectionLeave(&cookie);
-
-    } else if (strcmp(imMask->mode, "RGBA") == 0) {
+    } else if (imMask->mode == IMAGING_MODE_RGBA) {
         ImagingSectionEnter(&cookie);
         fill_mask_RGBA(imOut, ink, imMask, dx0, dy0, sx0, sy0, xsize, ysize, pixelsize);
         ImagingSectionLeave(&cookie);
-
-    } else if (strcmp(imMask->mode, "RGBa") == 0) {
+    } else if (imMask->mode == IMAGING_MODE_RGBa) {
         ImagingSectionEnter(&cookie);
         fill_mask_RGBa(imOut, ink, imMask, dx0, dy0, sx0, sy0, xsize, ysize, pixelsize);
         ImagingSectionLeave(&cookie);
-
     } else {
         (void)ImagingError_ValueError("bad transparency mask");
         return -1;
