@@ -1,10 +1,8 @@
 #include "Python.h"
 #include "Imaging.h"
 
-
 Py_ssize_t
-_imaging_read_pyFd(PyObject *fd, char* dest, Py_ssize_t bytes)
-{
+_imaging_read_pyFd(PyObject *fd, char *dest, Py_ssize_t bytes) {
     /* dest should be a buffer bytes long, returns length of read
        -1 on error */
 
@@ -29,16 +27,13 @@ _imaging_read_pyFd(PyObject *fd, char* dest, Py_ssize_t bytes)
     Py_DECREF(result);
     return length;
 
- err:
+err:
     Py_DECREF(result);
     return -1;
-
 }
 
 Py_ssize_t
-_imaging_write_pyFd(PyObject *fd, char* src, Py_ssize_t bytes)
-{
-
+_imaging_write_pyFd(PyObject *fd, char *src, Py_ssize_t bytes) {
     PyObject *result;
     PyObject *byteObj;
 
@@ -49,24 +44,20 @@ _imaging_write_pyFd(PyObject *fd, char* src, Py_ssize_t bytes)
     Py_DECREF(result);
 
     return bytes;
-
 }
 
 int
-_imaging_seek_pyFd(PyObject *fd, Py_ssize_t offset, int whence)
-{
+_imaging_seek_pyFd(PyObject *fd, Py_ssize_t offset, int whence) {
     PyObject *result;
 
     result = PyObject_CallMethod(fd, "seek", "ni", offset, whence);
 
     Py_DECREF(result);
     return 0;
-
 }
 
 Py_ssize_t
-_imaging_tell_pyFd(PyObject *fd)
-{
+_imaging_tell_pyFd(PyObject *fd) {
     PyObject *result;
     Py_ssize_t location;
 
